==> bootstrap-rytmreact-1.0.0.tgz: package/index.js <==
#!/usr/bin/env node
"use strict"

const chalk = require('chalk') // for colors in console.log
const mkdirp = require('mkdirp') // mkdir -p
const prompt = require('prompt') // prompt (user input)
const shell = require('shelljs') // to execute commands
const fs = require('fs') // file system
const __projectDir = process.cwd()

let dependencies = [
  "bootstrap",
  "connected-react-router",
  "history@^4.0.0",
  "immutable@^4.0.0-rc.12",
  "jquery",
  "popper.js",
  "react",
  "react-dom",
  "react-redux",
  "react-router-dom",
  "redux",
  "redux-form",
  "redux-thunk",
  "rytm-helpers",
  "seamless-immutable"
]
let devDependencies = [
  "babel-core@^6.0.0",
  "babel-loader@^7.0.0",
  "babel-preset-react",
  "babel-preset-stage-2",
  "css-loader",
  "node-sass",
  "path",
  "redux-devtools-extension",
  "sass-loader",
  "style-loader",
  "svgo",
  "uglifyjs-webpack-plugin",
  "webpack@^3.0.0",
  "webpack-dev-server@^3.0.0",
  "webpack-livereload-plugin"
]

// welcome
const welcome = () => {
  console.log(chalk.magenta('									'))
  console.log(chalk.magenta('            #############    TM 	'))
  console.log(chalk.magenta('           ################ 		'))
  console.log(chalk.magenta('          ################# 		'))
  console.log(chalk.magenta('         ##### ########### 		'))
  console.log(chalk.magenta('        #####  ######## 			'))
  console.log(chalk.magenta('       #####    ##### 			'))
  console.log(chalk.magenta('      #####      ##### 			'))
  console.log(chalk.magenta('     #####        ##### 			'))
  console.log(chalk.magenta('    #####          ##### 			'))
  console.log(chalk.magenta('									'))
}
const goodbye = () => {
  console.log(chalk.magenta('									'))
  console.log(chalk.magenta('	All good.	One love! '))
  console.log(chalk.magenta('									'))
}



const buildProject = () => {
  
  // # make directories
  mkdirp.sync('src/reducers');
  mkdirp.sync('src/scss');

  // ## webpack.config.js ##
  fs.copyFileSync(
    __dirname + '/templates/webpack.config.js', 
    __projectDir + "/webpack.config.js"
  )
  // ## reducer.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/reducers/reducer.js', 
    __projectDir + "/src/reducers/reducer.js"
  )
  // ## style.scss ##
  fs.copyFileSync(
    __dirname + '/templates/src/scss/style.scss', 
    __projectDir + "/src/scss/style.scss"
  )
  // ## App.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/App.js', 
    __projectDir + "/src/App.js"
  )
  // ## history.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/history.js', 
    __projectDir + "/src/history.js"
  )
  // ## index.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/index.js', 
    __projectDir + "/src/index.js"
  )
  // ## store.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/store.js', 
    __projectDir + "/src/store.js"
  )

  // npm install
  shell.exec("npm install " + dependencies.join(" "))
  // shell.exec("npm install --save-dev " + devDependencies.join(" "))
  goodbye()
}

// welcome msg
welcome()
// build project
buildProject()

==> bootstrap-rytmreact-1.0.1.tgz: package/index.js <==
#!/usr/bin/env node
"use strict"

const chalk = require('chalk') // for colors in console.log
const mkdirp = require('mkdirp') // mkdir -p
const prompt = require('prompt') // prompt (user input)
const shell = require('shelljs') // to execute commands
const fs = require('fs') // file system
const __projectDir = process.cwd()

let dependencies = [
  "bootstrap",
  "connected-react-router",
  "history@^4.0.0",
  "immutable@^4.0.0-rc.12",
  "jquery",
  "popper.js",
  "react",
  "react-dom",
  "react-redux",
  "react-router-dom",
  "redux",
  "redux-form",
  "redux-thunk",
  "rytm-helpers",
  "seamless-immutable"
]
let devDependencies = [
  "babel-core@^6.0.0",
  "babel-loader@^7.0.0",
  "babel-preset-react",
  "babel-preset-stage-2",
  "css-loader",
  "node-sass",
  "path",
  "redux-devtools-extension",
  "sass-loader",
  "style-loader",
  "svgo",
  "uglifyjs-webpack-plugin",
  "webpack@^3.0.0",
  "webpack-dev-server@^3.0.0",
  "webpack-livereload-plugin"
]

// welcome
const welcome = () => {
  console.log(chalk.magenta('									'))
  console.log(chalk.magenta('            #############    TM 	'))
  console.log(chalk.magenta('           ################ 		'))
  console.log(chalk.magenta('          ################# 		'))
  console.log(chalk.magenta('         ##### ########### 		'))
  console.log(chalk.magenta('        #####  ######## 			'))
  console.log(chalk.magenta('       #####    ##### 			'))
  console.log(chalk.magenta('      #####      ##### 			'))
  console.log(chalk.magenta('     #####        ##### 			'))
  console.log(chalk.magenta('    #####          ##### 			'))
  console.log(chalk.magenta('									'))
}
const goodbye = () => {
  console.log(chalk.magenta('									'))
  console.log(chalk.magenta('	All good.	One love! '))
  console.log(chalk.magenta('									'))
}



const buildProject = () => {
  
  // # make directories
  mkdirp.sync('src/reducers');
  mkdirp.sync('src/scss');

  // ## webpack.config.js ##
  fs.copyFileSync(
    __dirname + '/templates/webpack.config.js', 
    __projectDir + "/webpack.config.js"
  )
  // ## reducer.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/reducers/reducer.js', 
    __projectDir + "/src/reducers/reducer.js"
  )
  // ## style.scss ##
  fs.copyFileSync(
    __dirname + '/templates/src/scss/style.scss', 
    __projectDir + "/src/scss/style.scss"
  )
  // ## App.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/App.js', 
    __projectDir + "/src/App.js"
  )
  // ## history.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/history.js', 
    __projectDir + "/src/history.js"
  )
  // ## index.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/index.js', 
    __projectDir + "/src/index.js"
  )
  // ## store.js ##
  fs.copyFileSync(
    __dirname + '/templates/src/store.js', 
    __projectDir + "/src/store.js"
  )

  // npm install
  shell.exec("npm install " + dependencies.join(" "))
  shell.exec("npm install --save-dev " + devDependencies.join(" "))
  goodbye()
}

// welcome msg
welcome()
// build project
buildProject()
